@@ -28,6 +28,8 @@ from typing import Dict
 from typing import Tuple
 from typing import List
 from typing import Iterable
+from typing import Any
+from typing import Type
 import os
 import sys
 import unicodedata
@@ -41,7 +43,7 @@ try:
     # Enable new improved regex engine instead of backwards compatible
     # v0.  regex.match('ß', 'SS', regex.IGNORECASE) matches only with
     # the improved version!  See also: https://pypi.org/project/regex/
-    regex.DEFAULT_VERSION = regex.VERSION1
+    regex.DEFAULT_VERSION = regex.VERSION1 # pylint: disable=no-member
 except (ImportError,):
     # Use standard “re” module as a fallback:
     import re
@@ -77,12 +79,30 @@ except (ImportError,):
 # letter of a word until the candidate lookup table pops up.
 MAX_WORDS = 100
 
-class Dictionary:
-    '''A class to hold a hunspell dictionary
-    '''
-    def __init__(self, name: str = 'en_US') -> None:
+class Dictionary():
+    '''A class to hold a hunspell dictionary'''
+    # As soon as it is OK ot require Python >= 3.7, use these nicer type hints:
+    #
+    # _instances: Dict[Tuple[Type['Dictionary'], str], 'Dictionary'] = {}
+    #
+    # def __new__(cls: Type['Dictionary'], name: str = 'en_US') -> 'Dictionary':
+    #
+    # openSUSE Leap 15.4 still has only Python 3.6.
+    _instances: Dict[Tuple[Any, str], Any] = {}
+
+    def __new__(cls: Any, name: str = 'en_US') -> Any:
+        '''Caching instances of this class and reuse previously created instances'''
+        key = (cls, name)
+        if key not in cls._instances:
+            instance = super().__new__(cls)
+            cls._instances[key] = instance
+            instance._initialize(name=name)
+        return cls._instances[key]
+
+    def _initialize(self, name: str = 'en_US') -> None:
+        '''Initialize a Dictionary'''
         if DEBUG_LEVEL > 1:
-            LOGGER.debug('Dictionary.__init__(name=%s)\n', name)
+            LOGGER.debug('name=%s', name)
         self.name = name
         self.language = self.name.split('_')[0]
         self.dic_path = ''
@@ -127,33 +147,42 @@ class Dictionary:
                     LOGGER.warning(
                         'Language is “fi” but “import libvoikko” failed.')
                     return
-                self.voikko = libvoikko.Voikko('fi')
+                try:
+                    self.voikko = libvoikko.Voikko('fi')
+                except (libvoikko.VoikkoException,) as error:
+                    LOGGER.warning('Init of voikko failed: %s: %s',
+                                   error.__class__.__name__, error)
+                    self.voikko = None
                 return
             if IMPORT_ENCHANT_SUCCESSFUL:
                 try:
                     self.enchant_dict = enchant.Dict(self.name)
-                except enchant.errors.DictNotFoundError:
+                except enchant.errors.DictNotFoundError as error:
                     LOGGER.exception(
-                        'Error initializing enchant for %s', self.name)
+                        'Error initializing enchant for %s: %s: %s',
+                        self.name, error.__class__.__name__, error)
                     self.enchant_dict = None
-                except Exception:
+                except Exception as error: # pylint: disable=broad-except
                     LOGGER.exception(
-                        'Unknown error initializing enchant for %s',
-                        self.name)
+                        'Unexpected error initializing enchant for %s: %s: %s',
+                        self.name, error.__class__.__name__, error)
                     self.enchant_dict = None
             elif IMPORT_HUNSPELL_SUCCESSFUL and self.dic_path:
                 aff_path = self.dic_path.replace('.dic', '.aff')
                 try:
-                    self.pyhunspell_object = hunspell.HunSpell(
-                        self.dic_path, aff_path)
-                except hunspell.HunSpellError:
+                    self.pyhunspell_object = (
+                        hunspell.HunSpell( # pylint: disable=used-before-assignment
+                            self.dic_path, aff_path))
+                except hunspell.HunSpellError as error:
                     LOGGER.debug(
-                        'Error initializing hunspell for %s', self.name)
+                        'Error initializing hunspell for %s: %s: %s',
+                        self.name, error.__class__.__name__, error)
                     self.pyhunspell_object = None
-                except Exception:
+                except Exception as error: # pylint: disable=broad-except
                     LOGGER.debug(
-                        'Unknown error initializing hunspell for %s',
-                        self.name)
+                        'Unexpected error initializing hunspell for '
+                        '%s: %s: %s',
+                        self.name, error.__class__.__name__, error)
                     self.pyhunspell_object = None
 
     def spellcheck_enchant(self, word: str) -> bool:
@@ -343,7 +372,7 @@ class Hunspell:
     using a list of Hunspell dictionaries
     '''
     def __init__(self, dictionary_names: Iterable[str] = ()) -> None:
-        global DEBUG_LEVEL
+        global DEBUG_LEVEL # pylint: disable=global-statement
         try:
             DEBUG_LEVEL = int(
                 str(os.getenv('IBUS_TYPING_BOOSTER_DEBUG_LEVEL')))
@@ -467,6 +496,95 @@ class Hunspell:
             return False
         return True
 
+    def spellcheck_match_list(self, input_phrase: str) -> List[str]:
+        '''
+        Returns a list of dictionaries where input_phrase can be found
+
+        :param input_phrase: The word to be spellchecked
+        :return: A list of dictionary names which accept input phrase
+                 as a valid word.
+
+        Examples:
+
+        >>> h = Hunspell(['en_US', 'None', 'it_IT', 'fr_FR'])
+        >>> h.spellcheck_match_list('arrive')
+        ['en_US', 'fr_FR']
+        >>> h.spellcheck_match_list('arrivé')
+        ['fr_FR']
+        >>> h.spellcheck_match_list('ragazzo')
+        ['it_IT']
+        >>> h.spellcheck_match_list(' \t')
+        []
+        '''
+        match_list = []
+        if not input_phrase.strip():
+            return []
+        for dictionary in self._dictionaries:
+            if dictionary.spellcheck(input_phrase):
+                match_list.append(dictionary.name)
+        return match_list
+
+    def spellcheck_single_dictionary(self, words: Iterable[str] = ()) -> bool:
+        '''
+        Checks whether there is at least one dictionary where all words
+        in the input list spellcheck as True.
+
+        :param words: A list or tuple of words to spellcheck
+        :return: - False if at least one input word is empty
+                 - True if there is at least one dictionary where all
+                   words in the input list spellcheck as True, else False.
+
+        Examples:
+
+        >>> h = Hunspell(['en_US', 'fr_FR'])
+
+        All 3 words spellcheck True in the French dictionary:
+
+        >>> h.spellcheck_single_dictionary(('Je', 'suis', 'arrivé'))
+        True
+
+        Not a correct French sentence but all 3 words spellcheck True
+        in the French dictionary:
+
+        >>> h.spellcheck_single_dictionary(('Je', 'suis', 'arrive'))
+        True
+
+
+        Not all 3 words spellcheck True in the French dictionary and
+        not all 3 words spellcheck True in the English dictionary either:
+
+        >>> h.spellcheck_single_dictionary(('Je', 'suis', 'arrived'))
+        False
+
+        All 3 words spellcheck True in the English dictionary:
+
+        >>> h.spellcheck_single_dictionary(('I', 'have', 'arrived'))
+        True
+
+        Unfortunately these 3 words spellcheck True in the French dictionary
+        ('have' is a form of the verb 'haver', 'I' is the name of the letter):
+
+        >>> h.spellcheck_single_dictionary(('I', 'have', 'arrivé'))
+        True
+
+        If the input contains empty words the result is False:
+
+        >>> h.spellcheck_single_dictionary(('I', 'have', ''))
+        False
+        '''
+        if not words:
+            return False
+        for word in words:
+            if not word:
+                return False
+        for dictionary in self._dictionaries:
+            spellcheck_total = True
+            for word in words:
+                spellcheck_total &= dictionary.spellcheck(word)
+            if spellcheck_total:
+                return True
+        return False
+
     def suggest(self, input_phrase: str) -> List[Tuple[str, int]]:
         # pylint: disable=line-too-long
         '''Return completions or corrections for the input phrase
@@ -580,7 +698,7 @@ class Hunspell:
                                 for x in dictionary.word_pairs
                                 if regex_pattern.match(x[1])])
                         else:
-                            re_pattern = re.compile(
+                            re_pattern = re.compile( # pylint: disable=used-before-assignment
                                 re.escape(input_phrase_no_accents),
                                 re.IGNORECASE)
                             suggested_words.update([
@@ -655,6 +773,11 @@ def main() -> None:
     runs some tests and prints profiling data.
     '''
     log_handler = logging.StreamHandler(stream=sys.stderr)
+    log_formatter = logging.Formatter(
+        '%(asctime)s %(filename)s '
+        'line %(lineno)d %(funcName)s %(levelname)s: '
+        '%(message)s')
+    log_handler.setFormatter(log_formatter)
     LOGGER.setLevel(logging.DEBUG)
     LOGGER.addHandler(log_handler)
 
