@@ -18,7 +18,11 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>
-
+'''
+Main program of ibus-typing-booster
+'''
+from typing import Any
+from typing import Union
 import os
 import sys
 import argparse
@@ -26,40 +30,42 @@ import re
 import logging
 import logging.handlers
 from signal import signal, SIGTERM, SIGINT
-from gi import require_version
+# pylint: disable=wrong-import-position
+from gi import require_version # type: ignore
 require_version('IBus', '1.0')
-from gi.repository import IBus
+from gi.repository import IBus # type: ignore
+require_version('GLib', '2.0')
 from gi.repository import GLib
+# pylint: enable=wrong-import-position
 
-import factory
-import version
+import itb_version
 
 LOGGER = logging.getLogger('ibus-typing-booster')
 
 DEBUG_LEVEL = int(0)
 try:
-    DEBUG_LEVEL = int(os.getenv('IBUS_TYPING_BOOSTER_DEBUG_LEVEL'))
+    DEBUG_LEVEL = int(str(os.getenv('IBUS_TYPING_BOOSTER_DEBUG_LEVEL')))
 except (TypeError, ValueError):
     DEBUG_LEVEL = int(0)
 
-try:
+if os.getenv('IBUS_TYPING_BOOSTER_LOCATION'):
     ICON_DIR = os.path.join(
-        os.getenv('IBUS_TYPING_BOOSTER_LOCATION'),
+        str(os.getenv('IBUS_TYPING_BOOSTER_LOCATION')),
         'icons')
-except:
+else:
     ICON_DIR = os.path.join(
-        version.get_prefix(), 'share/ibus-typing-booster/icons')
+        itb_version.get_prefix(), 'share/ibus-typing-booster/icons')
 
-try:
+if os.getenv('IBUS_TYPING_BOOSTER_LIB_LOCATION'):
     SETUP_TOOL = os.path.join(
-        os.getenv('IBUS_TYPING_BOOSTER_LIB_LOCATION'),
+        str(os.getenv('IBUS_TYPING_BOOSTER_LIB_LOCATION')),
         'ibus-setup-typing-booster')
-except:
+else:
     SETUP_TOOL = os.path.join(
-        version.get_prefix(),
+        itb_version.get_prefix(),
         'libexec/ibus-setup-typing-booster')
 
-def parse_args():
+def parse_args() -> Any:
     '''Parse the command line arguments'''
     parser = argparse.ArgumentParser()
     parser.add_argument(
@@ -105,8 +111,30 @@ if _ARGS.profile:
     import io
     _PROFILE = cProfile.Profile()
 
+if _ARGS.xml:
+    from xml.etree.ElementTree import Element, SubElement, tostring
+else:
+    # Avoid importing factory when the --xml option is used because
+    # factory imports other stuff which imports Gtk and that needs a
+    # display.
+    #
+    # But by moving the import of factory here, it is possible to
+    # use the --xml option in an environment where there is no
+    # display without getting an error message like this:
+    #
+    #    $ env -u DISPLAY python3 main.py --xml
+    #    Unable to init server: Could not connect: Connection refused
+    #
+    # The --xml option is used by “ibus write-cache” which is used
+    # during rpm updates and then there is often no display and
+    # the above error message appears.
+    #
+    # See: https://bugzilla.redhat.com/show_bug.cgi?id=1711646
+    import factory
+
 class IMApp:
-    def __init__(self, exec_by_ibus):
+    '''Input method application class'''
+    def __init__(self, exec_by_ibus: bool) -> None:
         if DEBUG_LEVEL > 1:
             LOGGER.debug('IMApp.__init__(exec_by_ibus=%s)\n', exec_by_ibus)
         self.__mainloop = GLib.MainLoop()
@@ -121,13 +149,12 @@ class IMApp:
             self.__component = IBus.Component(
                 name="org.freedesktop.IBus.IbusTypingBooster",
                 description="Typing Booster Component",
-                version=version.get_version(),
+                version=itb_version.get_version(),
                 license="GPL",
                 author=("Mike FABIAN <mfabian@redhat.com>, "
                         + "Anish Patil <anish.developer@gmail.com>"),
                 homepage="http://mike-fabian.github.io/ibus-typing-booster",
                 textdomain="ibus-typing-booster")
-            # now we get IME info from self.__factory.db
             name = 'typing-booster'
             longname = 'Typing Booster'
             description = 'A completion input method to speedup typing.'
@@ -153,7 +180,8 @@ class IMApp:
             self.__component.add_engine(engine)
             self.__bus.register_component(self.__component)
 
-    def run(self):
+    def run(self) -> None:
+        '''Run the input method application'''
         if DEBUG_LEVEL > 1:
             LOGGER.debug('IMApp.run()\n')
         if _ARGS.profile:
@@ -161,12 +189,13 @@ class IMApp:
         self.__mainloop.run()
         self.__bus_destroy_cb()
 
-    def quit(self):
+    def quit(self) -> None:
+        '''Quit the input method application'''
         if DEBUG_LEVEL > 1:
             LOGGER.debug('IMApp.quit()\n')
         self.__bus_destroy_cb()
 
-    def __bus_destroy_cb(self, bus=None):
+    def __bus_destroy_cb(self, bus: Any = None) -> None:
         if DEBUG_LEVEL > 1:
             LOGGER.debug('IMApp.__bus_destroy_cb(bus=%s)\n', bus)
         if self.destroyed:
@@ -184,109 +213,120 @@ class IMApp:
             stats.print_stats('tabsqlite', 25)
             stats.print_stats('hunspell_suggest', 25)
             stats.print_stats('hunspell_table', 25)
+            stats.print_stats('itb_util', 25)
             stats.print_stats('itb_emoji', 25)
             LOGGER.info('Profiling info:\n%s', stats_stream.getvalue())
 
-def cleanup(ima_ins):
+def cleanup(ima_ins: IMApp) -> None:
+    '''
+    Clean up when the input method application was killed by a signal
+    '''
     ima_ins.quit()
     sys.exit()
 
-def indent(element, level=0):
+def indent(element: Any, level: int = 0) -> None:
     '''Use to format xml Element pretty :)'''
     i = "\n" + level*"    "
     if element:
         if not element.text or not element.text.strip():
             element.text = i + "    "
+        last_subelement = None
         for subelement in element:
+            last_subelement = subelement
             indent(subelement, level+1)
             if not subelement.tail or not subelement.tail.strip():
                 subelement.tail = i + "    "
-        if not subelement.tail or not subelement.tail.strip():
-            subelement.tail = i
+        if (last_subelement
+            and (not last_subelement.tail or not last_subelement.tail.strip())):
+            last_subelement.tail = i
     else:
         if level and (not element.tail or not element.tail.strip()):
             element.tail = i
 
-def main():
+def write_xml() -> None:
+    '''
+    Writes the XML to describe the engine(s) to standard output.
+    '''
+    egs = Element('engines')
+
+    for language in ('t',):
+        _engine = SubElement(egs, 'engine')
+
+        _name = SubElement(_engine, 'name')
+        _name.text = 'typing-booster'
+
+        _longname = SubElement(_engine, 'longname')
+        _longname.text = 'Typing Booster'
+
+        _language = SubElement(_engine, 'language')
+        _language.text = language
+
+        _license = SubElement(_engine, 'license')
+        _license.text = 'GPL'
+
+        _author = SubElement(_engine, 'author')
+        _author.text = (
+            'Mike FABIAN <mfabian@redhat.com>'
+            + ', Anish Patil <anish.developer@gmail.com>')
+
+        _icon = SubElement(_engine, 'icon')
+        _icon.text = os.path.join(ICON_DIR, 'ibus-typing-booster.svg')
+
+        _layout = SubElement(_engine, 'layout')
+        _layout.text = 'default'
+
+        _desc = SubElement(_engine, 'description')
+        _desc.text = 'A completion input method to speedup typing.'
+
+        _symbol = SubElement(_engine, 'symbol')
+        _symbol.text = '🚀'
+
+        _setup = SubElement(_engine, 'setup')
+        _setup.text = SETUP_TOOL
+
+        _icon_prop_key = SubElement(_engine, 'icon_prop_key')
+        _icon_prop_key.text = 'InputMode'
+
+    # now format the xmlout pretty
+    indent(egs)
+    egsout = tostring(egs, encoding='utf8', method='xml').decode('utf-8')
+    patt = re.compile(r'<\?.*\?>\n')
+    egsout = patt.sub('', egsout)
+    sys.stdout.buffer.write((egsout+'\n').encode('utf-8'))
+
+def main() -> None:
     '''Main program'''
-    if not _ARGS.xml:
-        if _ARGS.no_debug:
-            log_handler = logging.NullHandler()
-        else:
-            if not os.access(
-                    os.path.expanduser('~/.local/share/ibus-typing-booster'),
-                    os.F_OK):
-                os.system('mkdir -p ~/.local/share/ibus-typing-booster')
-            logfile = os.path.expanduser(
-                '~/.local/share/ibus-typing-booster/debug.log')
-            log_handler = logging.handlers.TimedRotatingFileHandler(
-                logfile,
-                when='midnight',
-                interval=1,
-                backupCount=7,
-                encoding='UTF-8',
-                delay=False,
-                utc=False,
-                atTime=None)
-        log_formatter = logging.Formatter(
-            '%(asctime)s %(filename)s '
-            'line %(lineno)d %(funcName)s %(levelname)s: '
-            '%(message)s')
-        log_handler.setFormatter(log_formatter)
-        LOGGER.setLevel(logging.DEBUG)
-        LOGGER.addHandler(log_handler)
-        LOGGER.info('********** STARTING **********')
-
     if _ARGS.xml:
-        from xml.etree.ElementTree import Element, SubElement, tostring
+        write_xml()
+        return
 
-        egs = Element('engines')
-
-        for language in ('t',):
-            _engine = SubElement(egs, 'engine')
-
-            _name = SubElement(_engine, 'name')
-            _name.text = 'typing-booster'
-
-            _longname = SubElement(_engine, 'longname')
-            _longname.text = 'Typing Booster'
-
-            _language = SubElement(_engine, 'language')
-            _language.text = language
-
-            _license = SubElement(_engine, 'license')
-            _license.text = 'GPL'
-
-            _author = SubElement(_engine, 'author')
-            _author.text = (
-                'Mike FABIAN <mfabian@redhat.com>'
-                + ', Anish Patil <anish.developer@gmail.com>')
-
-            _icon = SubElement(_engine, 'icon')
-            _icon.text = os.path.join(ICON_DIR, 'ibus-typing-booster.svg')
-
-            _layout = SubElement(_engine, 'layout')
-            _layout.text = 'default'
-
-            _desc = SubElement(_engine, 'description')
-            _desc.text = 'A completion input method to speedup typing.'
-
-            _symbol = SubElement(_engine, 'symbol')
-            _symbol.text = '🚀'
-
-            _setup = SubElement(_engine, 'setup')
-            _setup.text = SETUP_TOOL
-
-            _icon_prop_key = SubElement(_engine, 'icon_prop_key')
-            _icon_prop_key.text = 'InputMode'
-
-        # now format the xmlout pretty
-        indent(egs)
-        egsout = tostring(egs, encoding='utf8', method='xml').decode('utf-8')
-        patt = re.compile(r'<\?.*\?>\n')
-        egsout = patt.sub('', egsout)
-        sys.stdout.buffer.write((egsout+'\n').encode('utf-8'))
-        return 0
+    log_handler: Union[
+        logging.NullHandler, logging.handlers.TimedRotatingFileHandler] = (
+            logging.NullHandler())
+    if not _ARGS.no_debug:
+        if not os.access(
+                os.path.expanduser('~/.local/share/ibus-typing-booster'),
+                os.F_OK):
+            os.system('mkdir -p ~/.local/share/ibus-typing-booster')
+        logfile = os.path.expanduser(
+            '~/.local/share/ibus-typing-booster/debug.log')
+        log_handler = logging.handlers.TimedRotatingFileHandler(
+            logfile,
+            when='midnight',
+            interval=1,
+            backupCount=7,
+            encoding='UTF-8',
+            delay=False,
+            utc=False,
+            atTime=None)
+    log_formatter = logging.Formatter(
+        '%(asctime)s %(filename)s '
+        'line %(lineno)d %(funcName)s %(levelname)s: '
+        '%(message)s')
+    log_handler.setFormatter(log_formatter)
+    LOGGER.setLevel(logging.DEBUG)
+    LOGGER.addHandler(log_handler)
+    LOGGER.info('********** STARTING **********')
 
     if _ARGS.daemon:
         if os.fork():
@@ -299,7 +339,7 @@ def main():
         ima.run()
     except KeyboardInterrupt:
         ima.quit()
-    return 0
+    return
 
 if __name__ == "__main__":
     main()
