@@ -29,12 +29,16 @@ import signal
 import logging
 import logging.handlers
 
+# pylint: disable=wrong-import-position
 from gi import require_version # type: ignore
 require_version('Gtk', '3.0')
 from gi.repository import Gtk # type: ignore
+# pylint: enable=wrong-import-position
 
+# pylint: disable=import-error
 sys.path = [sys.path[0]+'/../engine'] + sys.path
 import itb_util
+# pylint: enable=import-error
 
 LOGGER = logging.getLogger('ibus-typing-booster')
 
@@ -50,8 +54,10 @@ class InputPurposeTest(Gtk.Window): # type: ignore
         self.connect('destroy-event', self.on_destroy_event)
         self.connect('delete-event', self.on_delete_event)
 
-        self._main_container = Gtk.VBox()
-        self.add(self._main_container)
+        self._main_container = Gtk.Box()
+        self._main_container.set_orientation(Gtk.Orientation.VERTICAL)
+        self._main_container.set_spacing(0)
+        self.add(self._main_container) # pylint: disable=no-member
 
         margin = 5
 
@@ -74,8 +80,7 @@ class InputPurposeTest(Gtk.Window): # type: ignore
         self._input_purpose_combobox.connect(
             'changed', self.on_input_purpose_combobox_changed)
 
-        self._main_container.pack_start(
-            self._input_purpose_combobox, False, False, 0)
+        self._main_container.add(self._input_purpose_combobox)
 
         self._input_hints = itb_util.InputHints.NONE
 
@@ -94,8 +99,7 @@ class InputPurposeTest(Gtk.Window): # type: ignore
             self._input_hints_checkbuttons[hint.name].set_vexpand(False)
             self._input_hints_checkbuttons[hint.name].connect(
                 'clicked', self.on_checkbutton, hint)
-            self._main_container.pack_start(
-                self._input_hints_checkbuttons[hint.name], False, False, 0)
+            self._main_container.add(self._input_hints_checkbuttons[hint.name])
 
         self._test_entry = Gtk.Entry()
         self._test_entry.set_margin_start(margin)
@@ -110,9 +114,10 @@ class InputPurposeTest(Gtk.Window): # type: ignore
         self._test_entry.set_input_hints(self._input_hints)
         self._test_entry.connect('notify::text', self.on_test_entry)
 
-        self._main_container.pack_start(self._test_entry, False, False, 0)
+        self._main_container.add(self._test_entry)
 
         self._test_text_view = Gtk.TextView()
+        self._test_text_view.set_wrap_mode(Gtk.WrapMode.WORD_CHAR)
         margin = 10
         self._test_text_view.set_margin_start(margin)
         self._test_text_view.set_margin_end(margin)
@@ -129,9 +134,9 @@ class InputPurposeTest(Gtk.Window): # type: ignore
         self._test_text_view_buffer.connect(
             'changed', self.on_test_text_view_buffer_changed)
 
-        self._main_container.pack_start(self._test_text_view, True, True, 0)
+        self._main_container.add(self._test_text_view)
 
-        self.show_all()
+        self.show_all() # pylint: disable=no-member
 
     def on_delete_event(self, *_args: Any) -> None: # pylint: disable=no-self-use
         '''
