@@ -22,21 +22,27 @@ This file implements test cases for compose sequences.
 '''
 
 import sys
-import os
 import logging
 import locale
 import unittest
 
+# pylint: disable=wrong-import-position
 from gi import require_version # type: ignore
 require_version('IBus', '1.0')
 from gi.repository import IBus # type: ignore
+# pylint: enable=wrong-import-position
 
 LOGGER = logging.getLogger('ibus-typing-booster')
 
 sys.path.insert(0, "../engine")
-import itb_util
+import itb_util # pylint: disable=import-error
 sys.path.pop(0)
 
+import testutils # pylint: disable=import-error
+
+# pylint: disable=missing-function-docstring
+# pylint: disable=missing-class-docstring
+
 class ComposeSequencesTestCase(unittest.TestCase):
     def setUp(self) -> None:
         locale.setlocale(locale.LC_CTYPE, 'en_US.UTF-8')
@@ -49,6 +55,7 @@ class ComposeSequencesTestCase(unittest.TestCase):
         self.assertEqual(True, True)
 
     def test_adding_and_deleting_compose_sequences(self) -> None:
+        # pylint: disable=protected-access
         self._compose_sequences._add_compose_sequence(
             '<Multi_key> <e> <m> <p> <t> <y>', '∅')
         available_keyvals = None
@@ -198,6 +205,7 @@ class ComposeSequencesTestCase(unittest.TestCase):
             [IBus.KEY_Multi_key,
              IBus.KEY_e,
              IBus.KEY_equal]))
+        # pylint: enable=protected-access
 
     def test_preedit_representations(self) -> None:
         self.assertEqual(
@@ -291,7 +299,35 @@ class ComposeSequencesTestCase(unittest.TestCase):
                  IBus.KEY_space]),
             '"')
 
-    def test_compose_cs_CZ(self) -> None:
+    def test_compose_arabic(self) -> None:
+        # /usr/share/X11/locale/en_US.UTF-8/Compose contains:
+        # # Arabic Lam-Alef ligatures
+        # <UFEFB>	:   "لا" # ARABIC LIGATURE LAM WITH ALEF
+        # <UFEF7>	:   "لأ" # ARABIC LIGATURE LAM WITH ALEF WITH HAMZA ABOVE
+        # <UFEF9>	:   "لإ" # ARABIC LIGATURE LAM WITH ALEF WITH HAMZA BELOW
+        # <UFEF5>	:   "لآ" # ARABIC LIGATURE LAM WITH ALEF WITH MADDA ABOVE
+        self.assertEqual(
+            self._compose_sequences.compose(
+                [0x0100FEFB]),
+                '\u0644\u0627')
+        self.assertEqual(
+            self._compose_sequences.compose(
+                [0x0100FEF7]),
+                '\u0644\u0623')
+        self.assertEqual(
+            self._compose_sequences.compose(
+                [0x0100FEF9]),
+                '\u0644\u0625')
+        self.assertEqual(
+            self._compose_sequences.compose(
+                [0x0100FEF5]),
+                '\u0644\u0622')
+
+    @unittest.skipIf(
+        testutils.set_locale_error('cs_CZ.UTF-8'),
+        f'Skipping, this test needs a locale which is not available: '
+        f'{testutils.set_locale_error("cs_CZ.UTF-8")}')
+    def test_compose_cs_CZ(self) -> None: # pylint: disable=invalid-name
         # /usr/share/X11/locale/cs_CZ.UTF-8/Compose overrides some of
         # the compose sequences from
         # /usr/share/X11/locale/en_US.UTF-8/Compose:
@@ -317,7 +353,11 @@ class ComposeSequencesTestCase(unittest.TestCase):
                  IBus.KEY_quotedbl]),
             'ä')
 
-    def test_compose_km_KH(self) -> None:
+    @unittest.skipIf(
+        testutils.set_locale_error('km_KH.UTF-8'),
+        f'Skipping, this test needs a locale which is not available: '
+        f'{testutils.set_locale_error("km_KH.UTF-8")}')
+    def test_compose_km_KH(self) -> None: # pylint: disable=invalid-name
         locale.setlocale(locale.LC_CTYPE, 'km_KH.UTF-8')
         self._compose_sequences = itb_util.ComposeSequences()
         # This sequence comes from
@@ -339,10 +379,14 @@ class ComposeSequencesTestCase(unittest.TestCase):
         # https://gitlab.freedesktop.org/xorg/lib/libx11/issues/106):
         self.assertEqual(
             self._compose_sequences.compose(
-                [0x17FF]),
+                [0x010017FF]),
             'ាំ')
 
-    def test_compose_pt_BR(self) -> None:
+    @unittest.skipIf(
+        testutils.set_locale_error('pt_BR.UTF-8'),
+        f'Skipping, this test needs a locale which is not available: '
+        f'{testutils.set_locale_error("pt_BR.UTF-8")}')
+    def test_compose_pt_BR(self) -> None: # pylint: disable=invalid-name
         # This sequence comes from
         # /usr/share/X11/locale/en_US.UTF-8/Compose and is not
         # overridden in /usr/share/X11/locale/pt_BR.UTF-8/:
@@ -431,7 +475,11 @@ class ComposeSequencesTestCase(unittest.TestCase):
                  IBus.KEY_quotedbl]),
             'ä')
 
-    def test_compose_pt_PT(self) -> None:
+    @unittest.skipIf(
+        testutils.set_locale_error('pt_PT.UTF-8'),
+        f'Skipping, this test needs a locale which is not available: '
+        f'{testutils.set_locale_error("pt_PT.UTF-8")}')
+    def test_compose_pt_PT(self) -> None: # pylint: disable=invalid-name
         # These sequences come from
         # /usr/share/X11/locale/en_US.UTF-8/Compose and is not
         # overridden in /usr/share/X11/locale/pt_PT.UTF-8/:
@@ -489,7 +537,11 @@ class ComposeSequencesTestCase(unittest.TestCase):
                  IBus.KEY_comma]),
             'Ų')
 
-    def test_compose_am_ET(self) -> None:
+    @unittest.skipIf(
+        testutils.set_locale_error('am_ET.UTF-8'),
+        f'Skipping, this test needs a locale which is not available: '
+        f'{testutils.set_locale_error("am_ET.UTF-8")}')
+    def test_compose_am_ET(self) -> None: # pylint: disable=invalid-name
         # These sequences come from
         # /usr/share/X11/locale/en_US.UTF-8/Compose:
         self.assertEqual(
@@ -510,20 +562,22 @@ class ComposeSequencesTestCase(unittest.TestCase):
         # all compose sequences from the am_ET.UTF-8 compose file):
         locale.setlocale(locale.LC_CTYPE, 'am_ET.UTF-8')
         self._compose_sequences = itb_util.ComposeSequences()
+        # pylint: disable=protected-access
         if (self._compose_sequences._locale_compose_file()
             != '/usr/share/X11/locale/am_ET.UTF-8/Compose'):
             self.skipTest(
                 '/usr/share/X11/locale/am_ET.UTF-8/Compose not available')
-        if self._compose_sequences.compose([0xFE75, 0x1200]) != '':
+        # pylint: enable=protected-access
+        if self._compose_sequences.compose([0x0100FE75, 0x01001200]) != '':
             self.skipTest(
                 'New Compose file updated by '
                 'Benno Schulenberg <bensberg@telfort.nl> '
                 'is installed, see: '
-                'https://gitlab.freedesktop.org/xorg/lib/libx11/-/commit/488b156fe2cc8aca6946a49236ec7b7698fceda4')
+                'https://gitlab.freedesktop.org/xorg/lib/libx11/-/commit/488b156fe2cc8aca6946a49236ec7b7698fceda4') # pylint: disable=line-too-long
         self.assertEqual(
             self._compose_sequences.compose(
                 [IBus.KEY_u,
-                 0x1200]),
+                 0x01001200]),
             'ሁ')
         self.assertEqual(
             self._compose_sequences.compose(
