@@ -24,36 +24,45 @@ This file implements test cases for suggestions from hunspell dictionaries
 import sys
 import unittest
 
-from gi import require_version # type: ignore
-require_version('IBus', '1.0')
-from gi.repository import IBus # type: ignore
-
-import testutils
-
+# pylint: disable=wrong-import-position
 sys.path.insert(0, "../engine")
-import hunspell_suggest
-import itb_util
+import hunspell_suggest # pylint: disable=import-error
+import itb_util # pylint: disable=import-error
 sys.path.pop(0)
 
+import testutils # pylint: disable=import-error
+# pylint: enable=wrong-import-position
+
 IMPORT_ENCHANT_SUCCESSFUL = False
 IMPORT_HUNSPELL_SUCCESSFUL = False
 try:
+    # pylint: disable=unused-import
     import enchant # type: ignore
+    # pylint: enable=unused-import
     IMPORT_ENCHANT_SUCCESSFUL = True
 except (ImportError,):
     try:
+        # pylint: disable=unused-import
         import hunspell # type: ignore
+        # pylint: enable=unused-import
         IMPORT_HUNSPELL_SUCCESSFUL = True
     except (ImportError,):
         pass
 
 IMPORT_LIBVOIKKO_SUCCESSFUL = False
 try:
+    # pylint: disable=unused-import
     import libvoikko # type: ignore
+    # pylint: enable=unused-import
     IMPORT_LIBVOIKKO_SUCCESSFUL = True
 except (ImportError,):
     pass
 
+# pylint: disable=missing-function-docstring
+# pylint: disable=missing-class-docstring
+# pylint: disable=invalid-name
+# pylint: disable=line-too-long
+
 class HunspellSuggestTestCase(unittest.TestCase):
     def setUp(self) -> None:
         self.maxDiff = None
@@ -184,44 +193,17 @@ class HunspellSuggestTestCase(unittest.TestCase):
     def test_en_US(self) -> None:
         h = hunspell_suggest.Hunspell(['en_US'])
         self.assertEqual(
+            h.suggest('camel'),
             [('Camel', 0),
              ('camel', 0),
              ('Camelot', 0),
              ('camellia', 0),
              ('camelhair', 0),
              ('Camelopardalis', 0),
-             ('CAM', -1),
-             ('Cal', -1),
-             ('Mel', -1),
-             ('cal', -1),
-             ('cam', -1),
-             ('Carl', -1),
-             ('Gael', -1),
-             ('Jame', -1),
-             ('call', -1),
              ('came', -1),
-             ('come', -1),
-             ('game', -1),
-             ('Jamal', -1),
-             ('Jamel', -1),
-             ('Ocaml', -1),
-             ('cable', -1),
              ('cameo', -1),
-             ('calmer', -1),
-             ('camels', -1),
-             ('comely', -1),
-             ('compel', -1),
-             ('gamely', -1),
-             ("Camel's", -1),
-             ('Camilla', -1),
-             ('Camille', -1),
-             ('Carmela', -1),
-             ('Carmelo', -1),
-             ("Jamel's", -1),
-             ("camel's", -1),
-             ('caramel', -1),
-             ('Carmella', -1)],
-            h.suggest('camel'))
+             ('came l', -1),
+             ('camels', -1)])
 
     @unittest.skipUnless(
         itb_util.get_hunspell_dictionary_wordlist('fr_FR')[0],
@@ -260,7 +242,7 @@ class HunspellSuggestTestCase(unittest.TestCase):
         "Skipping, requires python3-libvoikko version >= 4.3.")
     @unittest.skipIf(
         testutils.init_libvoikko_error(),
-        "Skipping, %s" % testutils.init_libvoikko_error())
+        f'Skipping, {testutils.init_libvoikko_error()}')
     def test_fi_FI_voikko(self) -> None:
         d = hunspell_suggest.Dictionary('fi_FI')
         self.assertEqual(d.has_spellchecking(), True)
@@ -305,7 +287,7 @@ class HunspellSuggestTestCase(unittest.TestCase):
         d = hunspell_suggest.Dictionary('en_US')
         self.assertEqual(
             d.spellcheck_suggest_enchant('kamel'),
-            ['Jamel', 'Camel', 'camel', 'Jamal', 'gamely'])
+            ['camel', 'Camel'])
 
     @unittest.skipUnless(
         IMPORT_HUNSPELL_SUCCESSFUL and not IMPORT_ENCHANT_SUCCESSFUL,
@@ -335,7 +317,7 @@ class HunspellSuggestTestCase(unittest.TestCase):
         "Skipping, requires python3-libvoikko version >= 4.3.")
     @unittest.skipIf(
         testutils.init_libvoikko_error(),
-        "Skipping, %s" % testutils.init_libvoikko_error())
+        f'Skipping, {testutils.init_libvoikko_error()}')
     def test_fi_FI_spellcheck_voikko(self) -> None:
         d = hunspell_suggest.Dictionary('fi_FI')
         self.assertEqual(d.spellcheck_voikko('kissa'), True)
@@ -348,7 +330,7 @@ class HunspellSuggestTestCase(unittest.TestCase):
         "Skipping, requires python3-libvoikko version >= 4.3.")
     @unittest.skipIf(
         testutils.init_libvoikko_error(),
-        "Skipping, %s" % testutils.init_libvoikko_error())
+        f'Skipping, {testutils.init_libvoikko_error()}')
     def test_fi_FI_spellcheck_suggest_voikko(self) -> None:
         d = hunspell_suggest.Dictionary('fi_FI')
         self.assertEqual(
