@@ -24,17 +24,22 @@ This file implements test cases for finding key codes for key values
 import sys
 import unittest
 
+# pylint: disable=wrong-import-position
 from gi import require_version # type: ignore
 require_version('IBus', '1.0')
 from gi.repository import IBus # type: ignore
 require_version('Gdk', '3.0')
 from gi.repository import Gdk
+# pylint: enable=wrong-import-position
 
 sys.path.insert(0, "../engine")
-import itb_util
+import itb_util # pylint: disable=import-error
 sys.path.pop(0)
 
-@unittest.skipIf(Gdk.Display.open('') == None, 'Display cannot be opened.')
+# pylint: disable=missing-class-docstring
+# pylint: disable=missing-function-docstring
+
+@unittest.skipIf(Gdk.Display.open('') is None, 'Display cannot be opened.')
 class KeyvalsToKeycodesTestCase(unittest.TestCase):
     def setUp(self) -> None:
         self._keyvals_to_keycodes = itb_util.KeyvalsToKeycodes()
