@@ -22,11 +22,14 @@ This file implements a few helper functions for test cases
 '''
 
 import sys
+import locale
 
 sys.path.insert(0, "../engine")
+# pylint: disable=wrong-import-position
 # pylint: disable=import-error
 import itb_util
 # pylint: enable=import-error
+# pylint: enable=wrong-import-position
 sys.path.pop(0)
 
 IMPORT_ENCHANT_SUCCESSFUL = False
@@ -36,7 +39,9 @@ try:
     IMPORT_ENCHANT_SUCCESSFUL = True
 except (ImportError,):
     try:
+        # pylint: disable=unused-import
         import hunspell # type: ignore
+        # pylint: enable=unused-import
         IMPORT_HUNSPELL_SUCCESSFUL = True
     except (ImportError,):
         pass
@@ -49,11 +54,21 @@ except (ImportError,):
     pass
 
 def get_libvoikko_version() -> str:
+    '''Return the version of libvoikko
+
+    If libvoikko is not available, return 0
+    '''
     if IMPORT_LIBVOIKKO_SUCCESSFUL:
         return str(libvoikko.Voikko.getVersion())
     return '0'
 
 def init_libvoikko_error() -> str:
+    '''
+    Checks whether an error happens during initilization of Voikko.
+
+    :return: '' (empty string) if Voikko initialization worked.
+             error message string if Voikko initialization failed.
+    '''
     if IMPORT_LIBVOIKKO_SUCCESSFUL:
         try:
             voikko = libvoikko.Voikko('fi')
@@ -89,8 +104,8 @@ def enchant_sanity_test(language: str = '', word: str = '') -> bool:
         return False
     if not itb_util.get_hunspell_dictionary_wordlist(language)[0]:
         return False
-    d = enchant.Dict(language)
-    if d.suggest(word):
+    enchant_dictionary = enchant.Dict(language)
+    if enchant_dictionary.suggest(word):
         return True
     return  False
 
@@ -112,10 +127,34 @@ def enchant_working_as_expected() -> bool:
     '''
     if not IMPORT_ENCHANT_SUCCESSFUL:
         return False
-    d = enchant.Dict('en_US')
-    if d.check('hedgehgo'):
+    enchant_dictionary = enchant.Dict('en_US')
+    if enchant_dictionary.check('hedgehgo'):
         return False
-    if (d.suggest('hedgehgo') !=
-        ['hedgehog', 'hedgerow', 'hedger', 'hedgers', 'hedging', "hedger's"]):
+    if (enchant_dictionary.suggest('hedgehgo') !=
+        ['hedgehog', 'hedgehop']):
         return False
     return True
+
+def set_locale_error(locale_name: str) -> str:
+    '''
+    Checks whether an error occurs when trying to set locale.
+
+    :return: '' (empty string) if setting this locale worked.
+             error message string if setting this locale failed.
+
+    It checks by trying to set LC_CTYPE and then restoring the old
+    value.
+    '''
+    (old_lc_ctype_locale,
+     old_lc_ctype_encoding) = locale.getlocale(locale.LC_CTYPE)
+    if not old_lc_ctype_locale:
+        old_lc_ctype_locale = 'en_US'
+    if not old_lc_ctype_encoding:
+        old_lc_ctype_encoding = 'UTF-8'
+    old_locale_name = old_lc_ctype_locale + '.' + old_lc_ctype_encoding
+    try:
+        locale.setlocale(locale.LC_CTYPE, locale_name)
+        locale.setlocale(locale.LC_CTYPE, old_locale_name)
+        return ''
+    except (locale.Error,) as error:
+        return f'{locale_name}: {str(error)}'
